package com.jpsoft.smart.modules.base.controller;

import com.github.pagehelper.Page;
import com.jpsoft.smart.modules.common.utils.PojoUtils;
import com.jpsoft.smart.modules.common.dto.Sort;
import com.jpsoft.smart.modules.common.dto.MessageResult;
import com.jpsoft.smart.modules.base.entity.CompanyInfo;
import com.jpsoft.smart.modules.base.service.CompanyInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.*;

@RestController
@RequestMapping("/base/companyInfo")
@Api(description = "companyInfo")
public class CompanyInfoController {
    private Logger logger = LoggerFactory.getLogger(getClass());

    @Autowired
    private CompanyInfoService companyInfoService;

    @ApiOperation(value="创建空记录")
    @GetMapping("create")
    public MessageResult<CompanyInfo> create(){
        MessageResult<CompanyInfo> msgResult = new MessageResult<>();

        CompanyInfo companyInfo = new CompanyInfo();

        msgResult.setData(companyInfo);
        msgResult.setResult(true);

        return msgResult;
    }
    
    @ApiOperation(value="添加信息")
    @PostMapping("add")
    public MessageResult<CompanyInfo> add(@RequestBody CompanyInfo companyInfo,@RequestAttribute String subject){
        MessageResult<CompanyInfo> msgResult = new MessageResult<>();

        try {
            companyInfo.setId(UUID.randomUUID().toString());
            companyInfo.setDelFlag(false);
            companyInfo.setCreateBy(subject);
            companyInfo.setCreateTime(new Date());
            
            int affectCount = companyInfoService.insert(companyInfo);

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(companyInfo);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("数据库添加失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

    @ApiOperation(value="获取信息")
    @GetMapping("edit/{id}")
    public MessageResult<CompanyInfo> edit(@PathVariable("id") String id){
        MessageResult<CompanyInfo> msgResult = new MessageResult<>();

        try {
            CompanyInfo companyInfo = companyInfoService.get(id);

            if (companyInfo != null) {
                msgResult.setResult(true);
                msgResult.setData(companyInfo);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("数据库不存在该记录!");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

    @ApiOperation(value="更新")
    @PostMapping("update")
    public MessageResult<CompanyInfo> update(@RequestBody CompanyInfo companyInfo,@RequestAttribute String subject){
        MessageResult<CompanyInfo> msgResult = new MessageResult<>();

        try {
            companyInfo.setUpdateBy(subject);
            companyInfo.setUpdateTime(new Date());
            
            int affectCount = companyInfoService.update(companyInfo);

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(companyInfo);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("数据库更新失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

	@ApiOperation(value="删除")
    @PostMapping("delete/{id}")
    public MessageResult<Integer> delete(@PathVariable("id") String id,@RequestAttribute String subject){
        MessageResult<Integer> msgResult = new MessageResult<>();

        try {
            CompanyInfo companyInfo = companyInfoService.get(id);
            companyInfo.setDelFlag(true);
            companyInfo.setUpdateBy(subject);
            companyInfo.setUpdateTime(new Date());

            int affectCount = companyInfoService.update(companyInfo);

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(affectCount);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("删除失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }


    @ApiOperation(value="批量删除")
    @PostMapping("batchDelete")
    public MessageResult<Integer> batchDelete(@RequestBody List<String> idList,@RequestAttribute String subject){
        MessageResult<Integer> msgResult = new MessageResult<>();

        try {
            int affectCount = 0;

            for (String id : idList) {
                CompanyInfo companyInfo = companyInfoService.get(id);
                companyInfo.setDelFlag(true);
                companyInfo.setUpdateBy(subject);
                companyInfo.setUpdateTime(new Date());

                affectCount += companyInfoService.update(companyInfo);
            }

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(affectCount);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("删除失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

    @ApiOperation(value="列表")
    @RequestMapping(value = "pageList",method = RequestMethod.POST)
    public MessageResult<Map> pageList(
            String id,
            @RequestParam(value="pageIndex",defaultValue="1") int pageIndex,
            @RequestParam(value="pageSize",defaultValue="20") int pageSize,
            @RequestAttribute String subject){

        //当前用户ID
        System.out.println(subject);

        MessageResult<Map> msgResult = new MessageResult<>();

        Map<String,Object> searchParams = new HashMap<>();

        List<Sort> sortList = new ArrayList<>();
        sortList.add(new Sort("id_","asc"));

        if (StringUtils.isNotEmpty(id)) {
            searchParams.put("id","%" + id + "%");
        }

        Page<CompanyInfo> page = companyInfoService.pageSearch(searchParams,pageIndex,pageSize,sortList);

        msgResult.setResult(true);
        msgResult.setData(PojoUtils.pageWrapper(page));

        return msgResult;
    }

    @ApiOperation(value="所有单位列表")
    @RequestMapping(value = "list",method = RequestMethod.POST)
    public MessageResult<List<CompanyInfo>> list(){
        MessageResult<List<CompanyInfo>> msgResult = new MessageResult<>();

        List<CompanyInfo> list = companyInfoService.list();

        msgResult.setResult(true);
        msgResult.setData(list);

        return msgResult;
    }
}
